@@ -1,12 +1,16 @@
 from __future__ import annotations
 
 import abc
+import datetime
 import decimal
 import itertools
 import logging
+import warnings
+import zoneinfo
 from collections.abc import Generator
 from collections.abc import Iterator
 from collections.abc import Mapping
+from io import BufferedReader
 from io import BytesIO
 from os import PathLike
 from pathlib import Path
@@ -26,7 +30,6 @@ import numpy as np
 import pandas as pd
 import pyarrow as pa
 import pyarrow.parquet as pq
-import pytz
 import zstandard
 from databento_dbn import FIXED_PRICE_SCALE
 from databento_dbn import UNDEF_PRICE
@@ -35,6 +38,7 @@ from databento_dbn import DBNDecoder
 from databento_dbn import Encoding
 from databento_dbn import InstrumentDefMsg
 from databento_dbn import InstrumentDefMsgV1
+from databento_dbn import InstrumentDefMsgV2
 from databento_dbn import Metadata
 from databento_dbn import RType
 from databento_dbn import Schema
@@ -45,7 +49,10 @@ from databento_dbn import VersionUpgradePolicy
 from databento.common.constants import DEFINITION_TYPE_MAX_MAP
 from databento.common.constants import SCHEMA_STRUCT_MAP
 from databento.common.constants import SCHEMA_STRUCT_MAP_V1
+from databento.common.constants import SCHEMA_STRUCT_MAP_V2
+from databento.common.enums import PriceType
 from databento.common.error import BentoError
+from databento.common.error import BentoWarning
 from databento.common.symbology import InstrumentMap
 from databento.common.types import DBNRecord
 from databento.common.types import Default
@@ -150,7 +157,7 @@ class FileDataSource(DataSource):
             )
 
         self._name = self._path.name
-        self.__buffer: IO[bytes] | None = None
+        self.__buffer: BufferedReader | None = None
 
     @property
     def name(self) -> str:
@@ -189,13 +196,13 @@ class FileDataSource(DataSource):
         return self._path
 
     @property
-    def reader(self) -> IO[bytes]:
+    def reader(self) -> BufferedReader:
         """
         Return a reader for this file.
 
         Returns
         -------
-        IO
+        BufferedReader
 
         """
         if self.__buffer is None:
@@ -259,14 +266,14 @@ class MemoryDataSource(DataSource):
         return self.__buffer.getbuffer().nbytes
 
     @property
-    def reader(self) -> IO[bytes]:
+    def reader(self) -> BytesIO:
         """
         Return a reader for this buffer. The reader beings at the start of the
         buffer.
 
         Returns
         -------
-        IO
+        BytesIO
 
         """
         self.__buffer.seek(0)
@@ -322,6 +329,8 @@ class DBNStore:
         Write the data to a file in JSON format.
     to_ndarray : np.ndarray
         The data as a numpy `ndarray`.
+    to_parquet
+        Write the data to a parquet file.
 
     Raises
     ------
@@ -376,7 +385,7 @@ class DBNStore:
     def __iter__(self) -> Generator[DBNRecord, None, None]:
         reader = self.reader
         decoder = DBNDecoder(
-            upgrade_policy=VersionUpgradePolicy.UPGRADE,
+            upgrade_policy=VersionUpgradePolicy.UPGRADE_TO_V3,
         )
         while True:
             raw = reader.read(DBNStore.DBN_READ_SIZE)
@@ -390,9 +399,12 @@ class DBNStore:
                         self._instrument_map.insert_symbol_mapping_msg(record)
                     yield record
             else:
+                # This call to decode is required to seek past the decoded records
+                # This behavior will be fixed in the next version of databento_dbn
+                _ = decoder.decode()
                 if len(decoder.buffer()) > 0:
-                    raise BentoError(
-                        "DBN file is truncated or contains an incomplete record",
+                    warnings.warn(
+                        BentoWarning("DBN file is truncated or contains an incomplete record"),
                     )
                 break
 
@@ -516,7 +528,7 @@ class DBNStore:
 
         Returns
         -------
-        BinaryIO
+        IO[bytes]
 
         See Also
         --------
@@ -524,13 +536,11 @@ class DBNStore:
 
         """
         if self.compression == Compression.ZSTD:
-            reader: IO[bytes] = zstandard.ZstdDecompressor().stream_reader(
+            return zstandard.ZstdDecompressor().stream_reader(
                 self._data_source.reader,
+                read_across_frames=True,
             )
-        else:
-            reader = self._data_source.reader
-
-        return reader
+        return self._data_source.reader
 
     @property
     def schema(self) -> Schema | None:
@@ -655,7 +665,7 @@ class DBNStore:
 
         Parameters
         ----------
-        data : BytesIO or bytes
+        data : BytesIO or bytes or IO[bytes]
             The bytes to read from.
 
         Returns
@@ -691,7 +701,7 @@ class DBNStore:
             self._instrument_map.clear()
         self._instrument_map.insert_json(json_data)
 
-    def replay(self, callback: Callable[[Any], None]) -> None:
+    def replay(self, callback: Callable[[DBNRecord], None]) -> None:
         """
         Replay data by passing records sequentially to the given callback.
 
@@ -770,10 +780,8 @@ class DBNStore:
         """
         if self.end is None:
             end_date = None
-        elif self.start.date() == self.end.date():
-            end_date = (self.start + pd.Timedelta(days=1)).date()
         else:
-            end_date = self.end
+            end_date = self.end.ceil(freq="D").date()
 
         return client.symbology.resolve(
             dataset=self.dataset,
@@ -792,6 +800,7 @@ class DBNStore:
         map_symbols: bool = True,
         compression: Compression | str = Compression.NONE,
         schema: Schema | str | None = None,
+        mode: Literal["w", "x"] = "w",
     ) -> None:
         """
         Write the data to a file in CSV format.
@@ -816,6 +825,8 @@ class DBNStore:
         schema : Schema or str, optional
             The DBN schema for the csv.
             This is only required when reading a DBN stream with mixed record types.
+        mode : str, default "w"
+            The file write mode to use, either "x" or "w".
 
         Raises
         ------
@@ -825,14 +836,15 @@ class DBNStore:
         """
         compression = validate_enum(compression, Compression, "compression")
         schema = validate_maybe_enum(schema, Schema, "schema")
+        file_path = validate_file_write_path(path, "path", exist_ok=mode == "w")
         if schema is None:
             if self.schema is None:
                 raise ValueError("a schema must be specified for mixed DBN data")
             schema = self.schema
 
-        with open(path, "xb") as output:
+        with open(file_path, f"{mode}b") as output:
             self._transcode(
-                output=output,
+                output=output,  # type: ignore [arg-type]
                 encoding=Encoding.CSV,
                 pretty_px=pretty_px,
                 pretty_ts=pretty_ts,
@@ -844,42 +856,46 @@ class DBNStore:
     @overload
     def to_df(
         self,
-        price_type: Literal["fixed", "float", "decimal"] = ...,
+        price_type: PriceType | str = ...,
         pretty_ts: bool = ...,
         map_symbols: bool = ...,
         schema: Schema | str | None = ...,
-        tz: pytz.BaseTzInfo | str = ...,
+        tz: datetime.tzinfo | str = ...,
         count: None = ...,
     ) -> pd.DataFrame: ...
 
     @overload
     def to_df(
         self,
-        price_type: Literal["fixed", "float", "decimal"] = ...,
+        price_type: PriceType | str = ...,
         pretty_ts: bool = ...,
         map_symbols: bool = ...,
         schema: Schema | str | None = ...,
-        tz: pytz.BaseTzInfo | str = ...,
+        tz: datetime.tzinfo | str = ...,
         count: int = ...,
     ) -> DataFrameIterator: ...
 
     def to_df(
         self,
-        price_type: Literal["fixed", "float", "decimal"] = "float",
+        price_type: PriceType | str = PriceType.FLOAT,
         pretty_ts: bool = True,
         map_symbols: bool = True,
         schema: Schema | str | None = None,
-        tz: pytz.BaseTzInfo | str | Default[pytz.BaseTzInfo] = Default[pytz.BaseTzInfo](
-            pytz.UTC,
+        tz: datetime.tzinfo | str | Default[datetime.tzinfo] = Default[datetime.tzinfo](
+            datetime.timezone.utc,
         ),
         count: int | None = None,
     ) -> pd.DataFrame | DataFrameIterator:
         """
         Return the data as a `pd.DataFrame`.
 
+        Notes
+        -----
+        The DataFrame index will be set to `ts_recv` if it exists in the schema, otherwise it will be set to `ts_event`.
+
         Parameters
         ----------
-        price_type : str, default "float"
+        price_type : PriceType or str, default "float"
             The price type to use for price fields.
             If "fixed", prices will have a type of `int` in fixed decimal format; each unit representing 1e-9 or 0.000000001.
             If "float", prices will have a type of `float`.
@@ -894,7 +910,7 @@ class DBNStore:
         schema : Schema or str, optional
             The DBN schema for the dataframe.
             This is only required when reading a DBN stream with mixed record types.
-        tz : pytz.BaseTzInfo or str, default UTC
+        tz : datetime.tzinfo or str, default UTC
             If `pretty_ts` is `True`, all timestamps will be converted to the specified timezone.
         count : int, optional
             If set, instead of returning a single `DataFrame` a `DataFrameIterator`
@@ -914,6 +930,7 @@ class DBNStore:
             If the DBN schema is unspecified and cannot be determined.
 
         """
+        price_type = validate_enum(price_type, PriceType, "price_type")
         schema = validate_maybe_enum(schema, Schema, "schema")
 
         if isinstance(tz, Default):
@@ -923,8 +940,13 @@ class DBNStore:
                 "A timezone was specified when `pretty_ts` is `False`. Did you mean to set `pretty_ts=True`?",
             )
 
-        if not isinstance(tz, pytz.BaseTzInfo):
-            tz = pytz.timezone(tz)
+        if isinstance(tz, str):
+            tz = zoneinfo.ZoneInfo(tz)
+        elif not isinstance(tz, datetime.tzinfo):
+            raise ValueError(
+                f"The value {tz!r} is not a valid datetime.tzinfo",
+            )
+
         if schema is None:
             if self.schema is None:
                 raise ValueError("a schema must be specified for mixed DBN data")
@@ -957,10 +979,11 @@ class DBNStore:
     def to_parquet(
         self,
         path: PathLike[str] | str,
-        price_type: Literal["fixed", "float"] = "float",
+        price_type: PriceType | str = PriceType.FLOAT,
         pretty_ts: bool = True,
         map_symbols: bool = True,
         schema: Schema | str | None = None,
+        mode: Literal["w", "x"] = "w",
         **kwargs: Any,
     ) -> None:
         """
@@ -968,6 +991,8 @@ class DBNStore:
 
         Parameters
         ----------
+        path: PathLike[str] or str
+            The file path to write the data to.
         price_type : str, default "float"
             The price type to use for price fields.
             If "fixed", prices will have a type of `int` in fixed decimal format; each unit representing 1e-9 or 0.000000001.
@@ -983,6 +1008,11 @@ class DBNStore:
         schema : Schema or str, optional
             The DBN schema for the parquet file.
             This is only required when reading a DBN stream with mixed record types.
+        mode : str, default "w"
+            The file write mode to use, either "x" or "w".
+        **kwargs : Any
+            Keyword arguments to pass to the `pyarrow.parquet.ParquetWriter`.
+            These can be used to override the default behavior of the writer.
 
         Raises
         ------
@@ -991,7 +1021,10 @@ class DBNStore:
             If the DBN schema is unspecified and cannot be determined.
 
         """
-        if price_type == "decimal":
+        file_path = validate_file_write_path(path, "path", exist_ok=mode == "w")
+        price_type = validate_enum(price_type, PriceType, "price_type")
+
+        if price_type == PriceType.DECIMAL:
             raise ValueError("the 'decimal' price type is not currently supported")
 
         schema = validate_maybe_enum(schema, Schema, "schema")
@@ -1015,8 +1048,8 @@ class DBNStore:
                     # Initialize the writer using the first DataFrame
                     parquet_schema = pa.Schema.from_pandas(frame)
                     writer = pq.ParquetWriter(
-                        where=path,
-                        schema=parquet_schema,
+                        where=kwargs.pop("where", file_path),
+                        schema=kwargs.pop("schema", parquet_schema),
                         **kwargs,
                     )
                 writer.write_table(
@@ -1029,7 +1062,12 @@ class DBNStore:
             if writer is not None:
                 writer.close()
 
-    def to_file(self, path: PathLike[str] | str) -> None:
+    def to_file(
+        self,
+        path: PathLike[str] | str,
+        mode: Literal["w", "x"] = "w",
+        compression: Compression | str | None = None,
+    ) -> None:
         """
         Write the data to a DBN file at the given path.
 
@@ -1037,6 +1075,10 @@ class DBNStore:
         ----------
         path : PathLike[str] or str
             The file path to write to.
+        mode : str, default "w"
+            The file write mode to use, either "x" or "w".
+        compression : Compression or str, optional
+            The compression format to write. If `None`, uses the same compression as the underlying data.
 
         Raises
         ------
@@ -1048,10 +1090,35 @@ class DBNStore:
             If path is not writable.
 
         """
-        file_path = validate_file_write_path(path, "path")
-        with open(file_path, mode="xb") as f:
-            f.write(self._data_source.reader.read())
-        self._data_source = FileDataSource(file_path)
+        compression = validate_maybe_enum(compression, Compression, "compression")
+        file_path = validate_file_write_path(path, "path", exist_ok=mode == "w")
+
+        writer: IO[bytes] | zstandard.ZstdCompressionWriter
+        if compression is None or compression == self.compression:
+            # Handle trivial case
+            with open(file_path, mode=f"{mode}b") as writer:
+                reader = self._data_source.reader
+                while chunk := reader.read(2**16):
+                    writer.write(chunk)
+            return
+
+        if compression == Compression.ZSTD:
+            writer = zstandard.ZstdCompressor(
+                write_checksum=True,
+            ).stream_writer(
+                open(file_path, mode=f"{mode}b"),
+                closefd=True,
+            )
+        else:
+            writer = open(file_path, mode=f"{mode}b")
+
+        try:
+            reader = self.reader
+
+            while chunk := reader.read(2**16):
+                writer.write(chunk)
+        finally:
+            writer.close()
 
     def to_json(
         self,
@@ -1061,6 +1128,7 @@ class DBNStore:
         map_symbols: bool = True,
         compression: Compression | str = Compression.NONE,
         schema: Schema | str | None = None,
+        mode: Literal["w", "x"] = "w",
     ) -> None:
         """
         Write the data to a file in JSON format.
@@ -1084,6 +1152,8 @@ class DBNStore:
         schema : Schema or str, optional
             The DBN schema for the json.
             This is only required when reading a DBN stream with mixed record types.
+        mode : str, default "w"
+            The file write mode to use, either "x" or "w".
 
         Raises
         ------
@@ -1093,14 +1163,16 @@ class DBNStore:
         """
         compression = validate_enum(compression, Compression, "compression")
         schema = validate_maybe_enum(schema, Schema, "schema")
+        file_path = validate_file_write_path(path, "path", exist_ok=mode == "w")
+
         if schema is None:
             if self.schema is None:
                 raise ValueError("a schema must be specified for mixed DBN data")
             schema = self.schema
 
-        with open(path, "xb") as output:
+        with open(file_path, f"{mode}b") as output:
             self._transcode(
-                output=output,
+                output=output,  # type: ignore [arg-type]
                 encoding=Encoding.JSON,
                 pretty_px=pretty_px,
                 pretty_ts=pretty_ts,
@@ -1234,8 +1306,10 @@ class DBNStore:
             transcoder.write(byte_chunk)
 
         if transcoder.buffer():
-            raise BentoError(
-                "DBN file is truncated or contains an incomplete record",
+            warnings.warn(
+                BentoWarning(
+                    "DBN file is truncated or contains an incomplete record",
+                ),
             )
 
         transcoder.flush()
@@ -1253,6 +1327,8 @@ class DBNStore:
         """
         if self.metadata.version == 1:
             return SCHEMA_STRUCT_MAP_V1
+        if self.metadata.version == 2:
+            return SCHEMA_STRUCT_MAP_V2
         return SCHEMA_STRUCT_MAP
 
 
@@ -1277,9 +1353,10 @@ class NDArrayStreamIterator(NDArrayIterator):
         count: int | None = None,
     ) -> None:
         self._reader = reader
-        self._dtype = np.dtype(dtype)
+        self._dtype: np.dtype[Any] = np.dtype(dtype)
         self._offset = offset
         self._count = count
+        self._close_on_next = False
 
         self._reader.seek(offset)
 
@@ -1287,21 +1364,30 @@ class NDArrayStreamIterator(NDArrayIterator):
         return self
 
     def __next__(self) -> np.ndarray[Any, Any]:
+        if self._close_on_next:
+            raise StopIteration
+
         if self._count is None:
             read_size = -1
         else:
             read_size = self._dtype.itemsize * max(self._count, 1)
 
         if buffer := self._reader.read(read_size):
+            loose_bytes = len(buffer) % self._dtype.itemsize
+            if loose_bytes != 0:
+                warnings.warn(
+                    BentoWarning("DBN file is truncated or contains an incomplete record"),
+                )
+                buffer = buffer[:-loose_bytes]
+                self._close_on_next = True  # decode one more buffer before stopping
+
             try:
                 return np.frombuffer(
                     buffer=buffer,
                     dtype=self._dtype,
                 )
-            except ValueError:
-                raise BentoError(
-                    "DBN file is truncated or contains an incomplete record",
-                )
+            except ValueError as exc:
+                raise BentoError("Cannot decode DBN stream") from exc
 
         raise StopIteration
 
@@ -1346,10 +1432,8 @@ class NDArrayBytesIterator(NDArrayIterator):
                 dtype=self._dtype,
                 count=num_records,
             )
-        except ValueError:
-            raise BentoError(
-                "DBN file is truncated or contains an incomplete record",
-            ) from None
+        except ValueError as exc:
+            raise BentoError("Cannot decode DBN stream") from exc
 
 
 class DataFrameIterator:
@@ -1364,8 +1448,8 @@ class DataFrameIterator:
         count: int | None,
         struct_type: type[DBNRecord],
         instrument_map: InstrumentMap,
-        tz: pytz.BaseTzInfo,
-        price_type: Literal["fixed", "float", "decimal"] = "float",
+        tz: datetime.tzinfo,
+        price_type: PriceType = PriceType.FLOAT,
         pretty_ts: bool = True,
         map_symbols: bool = True,
     ):
@@ -1387,7 +1471,7 @@ class DataFrameIterator:
             columns=self._struct_type._ordered_fields,
         )
 
-        if self._struct_type in (InstrumentDefMsg, InstrumentDefMsgV1):
+        if self._struct_type in (InstrumentDefMsg, InstrumentDefMsgV1, InstrumentDefMsgV2):
             self._format_definition_fields(df)
 
         self._format_hidden_fields(df)
@@ -1442,16 +1526,16 @@ class DataFrameIterator:
     def _format_px(
         self,
         df: pd.DataFrame,
-        price_type: Literal["fixed", "float", "decimal"],
+        price_type: PriceType,
     ) -> None:
         px_fields = self._struct_type._price_fields
 
-        if price_type == "decimal":
+        if price_type == PriceType.DECIMAL:
             df[px_fields] = (
                 df[px_fields].replace(UNDEF_PRICE, np.nan).applymap(decimal.Decimal)
                 / FIXED_PRICE_SCALE
             )
-        elif price_type == "float":
+        elif price_type == PriceType.FLOAT:
             df[px_fields] = df[px_fields].replace(UNDEF_PRICE, np.nan) / FIXED_PRICE_SCALE
         else:
             return  # do nothing
