@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+import warnings
 from collections.abc import Iterable
 from datetime import date
+from datetime import datetime
 from functools import partial
 from functools import singledispatch
 from io import BytesIO
@@ -219,16 +221,16 @@ def optional_date_to_string(value: date | str | None) -> str | None:
     if value is None:
         return None
 
-    return datetime_to_date_string(value)
+    return date_to_string(value)
 
 
-def datetime_to_string(value: pd.Timestamp | date | str | int) -> str:
+def datetime_to_string(value: pd.Timestamp | datetime | date | str | int) -> str:
     """
     Return a valid datetime string from the given value.
 
     Parameters
     ----------
-    value : pd.Timestamp or date or str
+    value : pd.Timestamp, datetime, date, str, or int
         The value to parse.
 
     Returns
@@ -240,17 +242,21 @@ def datetime_to_string(value: pd.Timestamp | date | str | int) -> str:
         return value
     elif isinstance(value, int):
         return str(value)
+    elif isinstance(value, date):
+        return value.isoformat()
+    elif isinstance(value, datetime):
+        return value.isoformat()
     else:
         return pd.to_datetime(value).isoformat()
 
 
-def datetime_to_date_string(value: pd.Timestamp | date | str | int) -> str:
+def date_to_string(value: pd.Timestamp | date | str | int) -> str:
     """
     Return a valid date string from the given value.
 
     Parameters
     ----------
-    value : pd.Timestamp or date or str
+    value : pd.Timestamp, date, str, or int
         The value to parse.
 
     Returns
@@ -260,21 +266,43 @@ def datetime_to_date_string(value: pd.Timestamp | date | str | int) -> str:
     """
     if isinstance(value, str):
         return value
+    elif isinstance(value, date):
+        return value.isoformat()
     elif isinstance(value, int):
+        warnings.warn(
+            "Passing an int to `start_date` or `end_date` is deprecated and will be removed in v0.59.0."
+            "Use a date or str instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         return str(value)
+    elif isinstance(value, pd.Timestamp):
+        warnings.warn(
+            "Passing a pandas Timestamp to `start_date` or `end_date` is deprecated and will be removed in v0.59.0."
+            "Use a date or str instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return pd.to_datetime(value).date().isoformat()
     else:
+        warnings.warn(
+            f"Passing a {type(value)} to `start_date` or `end_date` is deprecated and will be removed in v0.59.0."
+            "Use a date or str instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
         return pd.to_datetime(value).date().isoformat()
 
 
 def optional_datetime_to_string(
-    value: pd.Timestamp | date | str | int | None,
+    value: pd.Timestamp | datetime | date | str | int | None,
 ) -> str | None:
     """
     Return a valid datetime string from the given value (if not None).
 
     Parameters
     ----------
-    value : pd.Timestamp or date or str, optional
+    value : pd.Timestamp, datetime, date, str, or int, optional
         The value to parse.
 
     Returns
@@ -296,7 +324,7 @@ def datetime_to_unix_nanoseconds(
 
     Parameters
     ----------
-    value : pd.Timestamp or date or str or int
+    value : pd.Timestamp, date, str, or int
         The value to parse.
 
     Returns
@@ -306,26 +334,24 @@ def datetime_to_unix_nanoseconds(
     """
     if isinstance(value, int):
         return value  # no checking on integer values
-
-    if isinstance(value, date):
+    elif isinstance(value, date):
         return pd.to_datetime(value, utc=True).value
-
-    if isinstance(value, pd.Timestamp):
+    elif isinstance(value, pd.Timestamp):
         return value.value
+    else:
+        try:
+            nanoseconds = pd.to_datetime(value, utc=True).value
+        except Exception:  # different versions of pandas raise different exceptions
+            nanoseconds = pd.to_datetime(
+                int(value),
+                utc=True,
+            ).value
 
-    try:
-        nanoseconds = pd.to_datetime(value, utc=True).value
-    except Exception:  # different versions of pandas raise different exceptions
-        nanoseconds = pd.to_datetime(
-            int(value),
-            utc=True,
-        ).value
-
-    return nanoseconds
+        return nanoseconds
 
 
 def optional_datetime_to_unix_nanoseconds(
-    value: pd.Timestamp | str | int | None,
+    value: pd.Timestamp | date | str | int | None,
 ) -> int | None:
     """
     Return a valid UNIX nanosecond timestamp from the given value (if not
@@ -333,7 +359,7 @@ def optional_datetime_to_unix_nanoseconds(
 
     Parameters
     ----------
-    value : pd.Timestamp or date or str or int
+    value : pd.Timestamp, date, str, or int
         The value to parse.
 
     Returns
@@ -424,14 +450,14 @@ def convert_datetime_columns(df: pd.DataFrame, columns: list[str]) -> None:
         df[column] = df[column].apply(convert_to_datetime)
 
 
-def convert_ndjson_to_df(data: bytes, compressed: bool) -> pd.DataFrame:
+def convert_jsonl_to_df(data: bytes, compressed: bool) -> pd.DataFrame:
     """
-    Convert the given NDJSON bytes `data` to a pandas DataFrame.
+    Convert the given JSON lines bytes `data` to a pandas DataFrame.
 
     Parameters
     ----------
     data : bytes
-        The NDJSON data as bytes to be converted.
+        The JSON lines data as bytes to be converted.
     compressed : bool
         If the content is zstd compressed.
 
