@@ -4,11 +4,13 @@ import asyncio
 import hashlib
 import logging
 import warnings
+import zipfile
 from collections.abc import Iterable
 from concurrent.futures import ThreadPoolExecutor
 from concurrent.futures import as_completed
 from dataclasses import dataclass
 from datetime import date
+from datetime import datetime
 from os import PathLike
 from pathlib import Path
 from time import sleep
@@ -27,7 +29,6 @@ from requests.auth import HTTPBasicAuth
 from databento.common import API_VERSION
 from databento.common.constants import HTTP_STREAMING_READ_SIZE
 from databento.common.enums import Delivery
-from databento.common.enums import Packaging
 from databento.common.enums import SplitDuration
 from databento.common.error import BentoError
 from databento.common.error import BentoHttpError
@@ -39,7 +40,6 @@ from databento.common.parsing import optional_datetime_to_string
 from databento.common.parsing import optional_values_list_to_string
 from databento.common.parsing import symbols_list_to_list
 from databento.common.publishers import Dataset
-from databento.common.types import Default
 from databento.common.validation import validate_enum
 from databento.common.validation import validate_path
 from databento.common.validation import validate_semantic_string
@@ -47,7 +47,7 @@ from databento.common.validation import validate_semantic_string
 
 logger = logging.getLogger(__name__)
 
-BATCH_DOWNLOAD_MAX_RETRIES: Final = 3
+BATCH_DOWNLOAD_MAX_RETRIES: Final = 5
 
 
 class BatchHttpAPI(BentoHttpAPI):
@@ -64,8 +64,8 @@ class BatchHttpAPI(BentoHttpAPI):
         dataset: Dataset | str,
         symbols: Iterable[str | int] | str | int,
         schema: Schema | str,
-        start: pd.Timestamp | date | str | int,
-        end: pd.Timestamp | date | str | int | None = None,
+        start: pd.Timestamp | datetime | date | str | int,
+        end: pd.Timestamp | datetime | date | str | int | None = None,
         encoding: Encoding | str = "dbn",
         compression: Compression | str = "zstd",
         pretty_px: bool = False,
@@ -74,7 +74,6 @@ class BatchHttpAPI(BentoHttpAPI):
         split_symbols: bool = False,
         split_duration: SplitDuration | str = "day",
         split_size: int | None = None,
-        packaging: Packaging | str | None = None,
         delivery: Delivery | str = "download",
         stype_in: SType | str = "raw_symbol",
         stype_out: SType | str = "instrument_id",
@@ -95,16 +94,17 @@ class BatchHttpAPI(BentoHttpAPI):
             If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
         schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, default 'trades'  # noqa
             The data record schema for the request.
-        start : pd.Timestamp or date or str or int
-            The start datetime of the request time range (inclusive).
+        start : pd.Timestamp, datetime, date, str, or int
+            The start of the request time range (inclusive).
+            Filters on `ts_recv` if it exists in the schema, otherwise `ts_event`.
             Assumes UTC as timezone unless passed a tz-aware object.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int, optional
-            The end datetime of the request time range (exclusive).
+        end : pd.Timestamp, datetime, date, str, or int, optional
+            The end of the request time range (exclusive).
+            Filters on `ts_recv` if it exists in the schema, otherwise `ts_event`.
             Assumes UTC as timezone unless passed a tz-aware object.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-            Values are forward filled based on the resolution provided.
-            Defaults to the same value as `start`.
+            Defaults to the forward filled value of `start` based on the resolution provided.
         encoding : Encoding or str {'dbn', 'csv', 'json'}, default 'dbn'
             The data encoding.
         compression : Compression or str {'none', 'zstd'}, default 'zstd'
@@ -125,8 +125,7 @@ class BatchHttpAPI(BentoHttpAPI):
             A week starts on Sunday UTC.
         split_size : int, optional
             The maximum size (bytes) of each batched data file before being split.
-        packaging : Packaging or str {'none', 'zip', 'tar'}, optional
-            The archive type to package all batched data files in.
+            Must be an integer between 1e9 and 10e9 inclusive (1GB - 10GB).
         delivery : Delivery or str {'download', 's3', 'disk'}, default 'download'
             The delivery mechanism for the processed batched data files.
         stype_in : SType or str, default 'raw_symbol'
@@ -148,6 +147,7 @@ class BatchHttpAPI(BentoHttpAPI):
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
         symbols_list = symbols_list_to_list(symbols, stype_in_valid)
+
         data: dict[str, object | None] = {
             "dataset": validate_semantic_string(dataset, "dataset"),
             "start": datetime_to_string(start),
@@ -167,9 +167,6 @@ class BatchHttpAPI(BentoHttpAPI):
             "split_duration": str(
                 validate_enum(split_duration, SplitDuration, "split_duration"),
             ),
-            "packaging": (
-                str(validate_enum(packaging, Packaging, "packaging")) if packaging else None
-            ),
             "delivery": str(validate_enum(delivery, Delivery, "delivery")),
         }
 
@@ -187,8 +184,8 @@ class BatchHttpAPI(BentoHttpAPI):
 
     def list_jobs(
         self,
-        states: list[str] | str = "received,queued,processing,done",
-        since: pd.Timestamp | date | str | int | None = None,
+        states: Iterable[str] | str = "received,queued,processing,done",
+        since: pd.Timestamp | datetime | date | str | int | None = None,
     ) -> list[dict[str, Any]]:
         """
         Request all batch job details for the user account.
@@ -199,9 +196,9 @@ class BatchHttpAPI(BentoHttpAPI):
 
         Parameters
         ----------
-        states : list[str] or str, optional {'received', 'queued', 'processing', 'done', 'expired'}  # noqa
-            The filter for jobs states as a list of comma separated values.
-        since : pd.Timestamp or date or str or int, optional
+        states : Iterable[str] or str, optional {'received', 'queued', 'processing', 'done', 'expired'}  # noqa
+            The filter for jobs states as an iterable of comma separated values.
+        since : pd.Timestamp, datetime, date, str, or int, optional
             The filter for timestamp submitted (will not include jobs prior to this).
 
         Returns
@@ -253,7 +250,7 @@ class BatchHttpAPI(BentoHttpAPI):
         job_id: str,
         output_dir: PathLike[str] | str | None = None,
         filename_to_download: str | None = None,
-        enable_partial_downloads: Default[bool] = Default[bool](True),
+        keep_zip: bool = False,
     ) -> list[Path]:
         """
         Download a batch job or a specific file to `{output_dir}/{job_id}/`.
@@ -273,6 +270,9 @@ class BatchHttpAPI(BentoHttpAPI):
         filename_to_download : str, optional
             The specific file to download.
             If `None` then will download all files for the batch job.
+        keep_zip: bool, default False
+            If `True`, and `filename_to_download` is `None`, files
+            will be saved as a .zip archive in the `output_dir`.
 
         Returns
         -------
@@ -285,35 +285,49 @@ class BatchHttpAPI(BentoHttpAPI):
             If no files were found for the batch job.
         ValueError
             If a file fails to download.
+            If `keep_zip` is True and `filename_to_download` is not `None`
 
         """
-        # TODO: Remove after a reasonable deprecation period
-        if not isinstance(enable_partial_downloads, Default):
-            warnings.warn(
-                "The parameter `enable_partial_downloads` has been removed and will cause an error if set in the future. Partially downloaded files will always be resumed.",
-                category=BentoWarning,
-                stacklevel=2,
-            )
+        if keep_zip and filename_to_download:
+            raise ValueError("Cannot specify an individual file to download when `keep_zip=True`")
+
+        batch_download = _BatchJob(
+            self,
+            job_id=job_id,
+            output_dir=output_dir,
+        )
 
         if filename_to_download is None:
             filenames_to_download = None
         else:
             filenames_to_download = [filename_to_download]
 
-        batch_download = _BatchDownload(
-            self,
-            job_id=job_id,
-            output_dir=output_dir,
+        downloaded_files = batch_download.download(
             filenames_to_download=filenames_to_download,
         )
 
-        return batch_download.download()
+        if keep_zip:
+            return downloaded_files
+
+        extracted_files = []
+        for file_path in downloaded_files:
+            if file_path.suffix == ".zip":
+                with zipfile.ZipFile(file_path) as zip_file:
+                    for e in zip_file.namelist():
+                        extracted_files.append(file_path.parent / e)
+                    zip_file.extractall(path=file_path.parent)
+                file_path.unlink()  # remove the zip archive
+            else:
+                extracted_files.append(file_path)
+
+        return extracted_files
 
     async def download_async(
         self,
         output_dir: PathLike[str] | str,
         job_id: str,
         filename_to_download: str | None = None,
+        keep_zip: bool = False,
     ) -> list[Path]:
         """
         Asynchronously download a batch job or a specific file to
@@ -333,6 +347,9 @@ class BatchHttpAPI(BentoHttpAPI):
         filename_to_download : str, optional
             The specific file to download.
             If `None` then will download all files for the batch job.
+        keep_zip: bool, default False
+            If `True`, and `filename_to_download` is `None`, files
+            will be saved as a .zip archive in the `output_dir`.
 
         Returns
         -------
@@ -345,25 +362,46 @@ class BatchHttpAPI(BentoHttpAPI):
             If no files were found for the batch job.
         ValueError
             If a file fails to download.
+            If `keep_zip` is True and `filename_to_download` is not `None`
 
         """
+        if keep_zip and filename_to_download:
+            raise ValueError("Cannot specify an individual file to download when `keep_zip=True`")
+
+        batch_download = _BatchJob(
+            self,
+            job_id=job_id,
+            output_dir=output_dir,
+        )
+
         if filename_to_download is None:
             filenames_to_download = None
         else:
             filenames_to_download = [filename_to_download]
 
-        batch_download = _BatchDownload(
-            self,
-            job_id=job_id,
-            output_dir=output_dir,
+        downloaded_files = await batch_download.download_async(
             filenames_to_download=filenames_to_download,
         )
 
-        return await batch_download.download_async()
+        if keep_zip:
+            return downloaded_files
+
+        extracted_files = []
+        for file_path in downloaded_files:
+            if file_path.suffix == ".zip":
+                with zipfile.ZipFile(file_path) as zip_file:
+                    for e in zip_file.namelist():
+                        extracted_files.append(file_path.parent / e)
+                    zip_file.extractall(path=file_path.parent)
+                file_path.unlink()  # remove the zip archive
+            else:
+                extracted_files.append(file_path)
+
+        return extracted_files
 
     def _download_batch_file(
         self,
-        batch_download_file: _BatchDownloadFile,
+        batch_download_file: _BatchJob._BatchJobFile,
         output_path: Path,
     ) -> Path:
         """
@@ -419,6 +457,96 @@ class BatchHttpAPI(BentoHttpAPI):
                     with open(output_path, mode=mode) as f:
                         for chunk in response.iter_content(chunk_size=HTTP_STREAMING_READ_SIZE):
                             f.write(chunk)
+
+                            # Successfully wrote some data, reset attempts counter
+                            if attempts > 0:
+                                attempts = 0
+                                logger.info(f"Resumed download of {output_path.name}.")
+            except BentoHttpError as exc:
+                if exc.http_status == 429:
+                    wait_time = int(exc.headers.get("Retry-After", 1))
+                    sleep(wait_time)
+                    continue  # try again
+                raise
+            except Exception as exc:
+                if attempts < BATCH_DOWNLOAD_MAX_RETRIES:
+                    attempts += 1
+                    logger.error(
+                        f"Retrying download of {output_path.name} due to error, "
+                        f"{attempts}/{BATCH_DOWNLOAD_MAX_RETRIES}: {exc}",
+                    )
+                    continue  # try again
+                raise BentoError(f"Error downloading file: {exc}") from None
+            else:
+                break
+
+        logger.debug("Download of %s completed", output_path.name)
+        hash_algo, _, hash_hex = batch_download_file.hash_str.partition(":")
+
+        if hash_algo == "sha256":
+            output_hash = hashlib.new(hash_algo)
+            with open(output_path, "rb") as fd:
+                while chunk := fd.read(32_000_000):
+                    output_hash.update(chunk)
+
+            if output_hash.hexdigest() != hash_hex:
+                warn_msg = f"Downloaded file failed checksum validation: {output_path.name}"
+                logger.warning(warn_msg)
+                warnings.warn(warn_msg, category=BentoWarning)
+        else:
+            logger.warning(
+                "Skipping %s checksum because %s is not supported",
+                output_path.name,
+                hash_algo,
+            )
+
+        return output_path
+
+    def _download_batch_zip(
+        self,
+        batch_download_url: str,
+        output_path: Path,
+    ) -> Path:
+        """
+        Download all batch files as a .zip archive.
+
+        Parameters
+        ----------
+        batch_download_url : _BatchDownloadFile
+            The batch download URL for the zipfile, should contain the job ID appended with .zip.
+        output_path : Path
+            The output path of the file.
+
+        Returns
+        -------
+        Path
+
+        Raises
+        ------
+        BentoError
+            If the file fails to download.
+
+        """
+        attempts = 0
+        logger.info(
+            "Downloading batch job zip to %s",
+            output_path,
+        )
+        while True:
+            headers: dict[str, str] = self._headers.copy()
+
+            try:
+                with requests.get(
+                    url=batch_download_url,
+                    headers=headers,
+                    auth=HTTPBasicAuth(username=self._key, password=""),
+                    allow_redirects=True,
+                    stream=True,
+                ) as response:
+                    check_http_error(response)
+                    with open(output_path, mode="wb") as f:
+                        for chunk in response.iter_content(chunk_size=HTTP_STREAMING_READ_SIZE):
+                            f.write(chunk)
             except BentoHttpError as exc:
                 if exc.http_status == 429:
                     wait_time = int(exc.headers.get("Retry-After", 1))
@@ -434,38 +562,13 @@ class BatchHttpAPI(BentoHttpAPI):
                     continue  # try again
                 raise BentoError(f"Error downloading file: {exc}") from None
             else:
-                break
-
-        logger.debug("Download of %s completed", output_path.name)
-        hash_algo, _, hash_hex = batch_download_file.hash_str.partition(":")
-
-        if hash_algo == "sha256":
-            output_hash = hashlib.sha256(output_path.read_bytes())
-            if output_hash.hexdigest() != hash_hex:
-                warn_msg = f"Downloaded file failed checksum validation: {output_path.name}"
-                logger.warning(warn_msg)
-                warnings.warn(warn_msg, category=BentoWarning)
-        else:
-            logger.warning(
-                "Skipping %s checksum because %s is not supported",
-                output_path.name,
-                hash_algo,
-            )
-
-        return output_path
+                logger.debug("Download of %s completed", output_path.name)
+                return output_path
 
 
-@dataclass
-class _BatchDownloadFile:
-    filename: str
-    hash_str: str
-    https_url: str
-    size: int
-
-
-class _BatchDownload:
+class _BatchJob:
     """
-    Helper class for downloading multiple batch files.
+    Helper class for downloading multiple batch files from a job.
 
     Supports sync and async downloads using a shared `ThreadPoolExecutor`.
 
@@ -475,12 +578,18 @@ class _BatchDownload:
         thread_name_prefix="databento_batch",
     )
 
+    @dataclass
+    class _BatchJobFile:
+        filename: str
+        hash_str: str
+        https_url: str
+        size: int
+
     def __init__(
         self,
         batch_http_api: BatchHttpAPI,
         job_id: str,
         output_dir: PathLike[str] | str | None = None,
-        filenames_to_download: Iterable[str] | None = None,
     ):
         if output_dir is None:
             output_dir = Path.cwd()
@@ -491,10 +600,10 @@ class _BatchDownload:
             logger.error(error_message)
             raise RuntimeError(error_message)
 
-        filenames_to_download = (
-            set(filenames_to_download) if filenames_to_download is not None else None
-        )
-        target_files = []
+        zip_filename = f"{job_id}.zip"
+        zip_url = None
+
+        batch_files = []
         for file_detail in job_details:
             try:
                 filename = str(file_detail["filename"])
@@ -515,55 +624,112 @@ class _BatchDownload:
                     "'download' delivery is not available for this job.",
                 ) from None
 
-            if filenames_to_download is None or filename in filenames_to_download:
-                target_files.append(
-                    _BatchDownloadFile(
-                        filename=filename,
-                        hash_str=hash_digest,
-                        https_url=https_url,
-                        size=size,
-                    ),
-                )
+            if zip_url is None:
+                zip_url = urls["https"].replace(filename, zip_filename)
 
-        self._batch_http_api = batch_http_api
-        self._output_dir = validate_path(output_dir, "output_dir") / job_id
-        self._target_files = target_files
-
-    def download(self) -> list[Path]:
-        self._output_dir.mkdir(exist_ok=True)
-
-        tasks = []
-        for target in self._target_files:
-            tasks.append(
-                self._executor.submit(
-                    self._batch_http_api._download_batch_file,
-                    target,
-                    self._output_dir / target.filename,
+            batch_files.append(
+                _BatchJob._BatchJobFile(
+                    filename=filename,
+                    hash_str=hash_digest,
+                    https_url=https_url,
+                    size=size,
                 ),
             )
 
+        if not batch_files or not zip_url:
+            raise ValueError(f"No job files for {job_id}.")
+
+        self._zip_filename = zip_filename
+        self._zip_url = zip_url
+        self._batch_http_api = batch_http_api
+        self._output_dir = validate_path(output_dir, "output_dir") / job_id
+        self._batch_files = batch_files
+
+    def download(
+        self,
+        filenames_to_download: Iterable[str] | None,
+    ) -> list[Path]:
+        self._output_dir.mkdir(
+            exist_ok=True,
+            parents=True,
+        )
+
         file_paths = []
+        tasks = []
+
+        if filenames_to_download is None:
+            tasks.append(
+                self._executor.submit(
+                    self._batch_http_api._download_batch_zip,
+                    self._zip_url,
+                    self._output_dir / self._zip_filename,
+                ),
+            )
+        else:
+            filenames_to_download = set(filenames_to_download)
+            for batch_file in self._batch_files:
+                if not filenames_to_download:
+                    break
+
+                if batch_file.filename not in filenames_to_download:
+                    continue
+
+                tasks.append(
+                    self._executor.submit(
+                        self._batch_http_api._download_batch_file,
+                        batch_file,
+                        self._output_dir / batch_file.filename,
+                    ),
+                )
+                filenames_to_download.remove(batch_file.filename)
+
         for completed in as_completed(tasks):
             path = completed.result()
             file_paths.append(path)
 
         return file_paths
 
-    async def download_async(self) -> list[Path]:
-        self._output_dir.mkdir(exist_ok=True)
+    async def download_async(
+        self,
+        filenames_to_download: Iterable[str] | None,
+    ) -> list[Path]:
+        self._output_dir.mkdir(
+            exist_ok=True,
+            parents=True,
+        )
 
+        file_paths: list[Path] = []
         tasks = []
-        for target in self._target_files:
+
+        if filenames_to_download is None:
             tasks.append(
                 asyncio.get_running_loop().run_in_executor(
                     self._executor,
-                    self._batch_http_api._download_batch_file,
-                    target,
-                    self._output_dir / target.filename,
+                    self._batch_http_api._download_batch_zip,
+                    self._zip_url,
+                    self._output_dir / self._zip_filename,
                 ),
             )
+        else:
+            filenames_to_download = set(filenames_to_download)
+
+            tasks = []
+            for batch_file in self._batch_files:
+                if not filenames_to_download:
+                    break
+
+                if batch_file.filename not in filenames_to_download:
+                    continue
+
+                tasks.append(
+                    asyncio.get_running_loop().run_in_executor(
+                        self._executor,
+                        self._batch_http_api._download_batch_file,
+                        batch_file,
+                        self._output_dir / batch_file.filename,
+                    ),
+                )
 
-        file_paths = []
         for completed in asyncio.as_completed(tasks):
             try:
                 path = await completed
