@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from collections.abc import Iterable
 from datetime import date
+from datetime import datetime
 from typing import Any
 
 import pandas as pd
@@ -31,7 +32,7 @@ class MetadataHttpAPI(BentoHttpAPI):
         super().__init__(key=key, gateway=gateway)
         self._base_url = gateway + f"/v{API_VERSION}/metadata"
 
-    def list_publishers(self) -> list[dict[str, Any]]:
+    def list_publishers(self) -> list[dict[str, int | str]]:
         """
         Request all publishers from Databento.
 
@@ -41,7 +42,7 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        list[dict[str, Any]]
+        list[dict[str, int | str]]
 
         """
         response: Response = self._get(
@@ -120,7 +121,7 @@ class MetadataHttpAPI(BentoHttpAPI):
         self,
         schema: Schema | str,
         encoding: Encoding | str,
-    ) -> list[dict[str, Any]]:
+    ) -> list[dict[str, str]]:
         """
         List all fields for a particular schema and encoding from Databento.
 
@@ -135,7 +136,7 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        list[dict[str, Any]]
+        list[dict[str, str]]
             A list of field details.
 
         """
@@ -188,7 +189,7 @@ class MetadataHttpAPI(BentoHttpAPI):
         dataset: Dataset | str,
         start_date: date | str | None = None,
         end_date: date | str | None = None,
-    ) -> dict[str, Any]:
+    ) -> list[dict[str, str | None]]:
         """
         Get the per date dataset conditions from Databento.
 
@@ -209,7 +210,7 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        dict[str, Any]
+        list[dict[str, str | None]]
 
         """
         params: list[tuple[str, str | None]] = [
@@ -230,7 +231,8 @@ class MetadataHttpAPI(BentoHttpAPI):
         dataset: Dataset | str,
     ) -> dict[str, str]:
         """
-        Request the available range for the dataset from Databento.
+        Request the available range for the dataset given the user's
+        entitlements.
 
         Makes a GET `/metadata.get_dataset_range` HTTP request.
 
@@ -241,7 +243,7 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        dict[str, str]
+        dict[str, str | dict[str, str]]
             The available range for the dataset.
 
         """
@@ -260,8 +262,8 @@ class MetadataHttpAPI(BentoHttpAPI):
     def get_record_count(
         self,
         dataset: Dataset | str,
-        start: pd.Timestamp | date | str | int,
-        end: pd.Timestamp | date | str | int | None = None,
+        start: pd.Timestamp | datetime | date | str | int,
+        end: pd.Timestamp | datetime | date | str | int | None = None,
         symbols: Iterable[str | int] | str | int | None = None,
         schema: Schema | str = "trades",
         stype_in: SType | str = "raw_symbol",
@@ -276,16 +278,15 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code for the request.
-        start : pd.Timestamp or date or str or int
+        start : pd.Timestamp, datetime, date, str, or int
             The start datetime for the request range (inclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int, optional
+        end : pd.Timestamp, datetime, date, str, or int, optional
             The end datetime for the request range (exclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-            Values are forward filled based on the resolution provided.
-            Defaults to the same value as `start`.
+            Defaults to the forward filled value of `start` based on the resolution provided.
         symbols : Iterable[str | int] or str or int, optional
             The instrument symbols to filter for. Takes up to 2,000 symbols per request.
             If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
@@ -304,22 +305,22 @@ class MetadataHttpAPI(BentoHttpAPI):
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
         symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
-        params: list[tuple[str, str | None]] = [
-            ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("symbols", ",".join(symbols_list)),
-            ("schema", str(validate_enum(schema, Schema, "schema"))),
-            ("start", optional_datetime_to_string(start)),
-            ("end", optional_datetime_to_string(end)),
-            ("stype_in", str(stype_in_valid)),
-        ]
+        data: dict[str, str | None] = {
+            "dataset": validate_semantic_string(dataset, "dataset"),
+            "symbols": ",".join(symbols_list),
+            "schema": str(validate_enum(schema, Schema, "schema")),
+            "start": optional_datetime_to_string(start),
+            "end": optional_datetime_to_string(end),
+            "stype_in": str(stype_in_valid),
+        }
 
         # Optional Parameters
         if limit is not None:
-            params.append(("limit", str(limit)))
+            data["limit"] = str(limit)
 
-        response: Response = self._get(
+        response: Response = self._post(
             url=self._base_url + ".get_record_count",
-            params=params,
+            data=data,
             basic_auth=True,
         )
 
@@ -328,8 +329,8 @@ class MetadataHttpAPI(BentoHttpAPI):
     def get_billable_size(
         self,
         dataset: Dataset | str,
-        start: pd.Timestamp | date | str | int,
-        end: pd.Timestamp | date | str | int | None = None,
+        start: pd.Timestamp | datetime | date | str | int,
+        end: pd.Timestamp | datetime | date | str | int | None = None,
         symbols: Iterable[str | int] | str | int | None = None,
         schema: Schema | str = "trades",
         stype_in: SType | str = "raw_symbol",
@@ -345,17 +346,16 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code for the request.
-        start : pd.Timestamp or date or str or int
+        start : pd.Timestamp, datetime, date, str, or int
             The start datetime for the request range (inclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int, optional
+        end : pd.Timestamp, datetime, date, str, or int, optional
             The end datetime for the request range (exclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-            Values are forward filled based on the resolution provided.
-            Defaults to the same value as `start`.
-        symbols : Iterable[str | int] or str or int, optional
+            Defaults to the forward filled value of `start` based on the resolution provided.
+        symbols : Iterable[str | int] or str, or int, optional
             The instrument symbols to filter for. Takes up to 2,000 symbols per request.
             If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
         schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, default 'trades'  # noqa
@@ -373,22 +373,22 @@ class MetadataHttpAPI(BentoHttpAPI):
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
         symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
-        params: list[tuple[str, str | None]] = [
-            ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("start", datetime_to_string(start)),
-            ("end", optional_datetime_to_string(end)),
-            ("symbols", ",".join(symbols_list)),
-            ("schema", str(validate_enum(schema, Schema, "schema"))),
-            ("stype_in", str(stype_in_valid)),
-            ("stype_out", str(SType.INSTRUMENT_ID)),
-        ]
+        data: dict[str, str | None] = {
+            "dataset": validate_semantic_string(dataset, "dataset"),
+            "start": datetime_to_string(start),
+            "end": optional_datetime_to_string(end),
+            "symbols": ",".join(symbols_list),
+            "schema": str(validate_enum(schema, Schema, "schema")),
+            "stype_in": str(stype_in_valid),
+            "stype_out": str(SType.INSTRUMENT_ID),
+        }
 
         if limit is not None:
-            params.append(("limit", str(limit)))
+            data["limit"] = str(limit)
 
-        response: Response = self._get(
+        response: Response = self._post(
             url=self._base_url + ".get_billable_size",
-            params=params,
+            data=data,
             basic_auth=True,
         )
 
@@ -397,8 +397,8 @@ class MetadataHttpAPI(BentoHttpAPI):
     def get_cost(
         self,
         dataset: Dataset | str,
-        start: pd.Timestamp | date | str | int,
-        end: pd.Timestamp | date | str | int | None = None,
+        start: pd.Timestamp | datetime | date | str | int,
+        end: pd.Timestamp | datetime | date | str | int | None = None,
         mode: FeedMode | str = "historical-streaming",
         symbols: Iterable[str | int] | str | int | None = None,
         schema: Schema | str = "trades",
@@ -407,7 +407,8 @@ class MetadataHttpAPI(BentoHttpAPI):
     ) -> float:
         """
         Request the cost in US dollars for historical streaming or batched
-        files from Databento.
+        files from Databento. This cost respects any discounts provided by flat
+        rate plans.
 
         Makes a `GET /metadata.get_cost` HTTP request.
 
@@ -415,16 +416,15 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code for the request.
-        start : pd.Timestamp or date or str or int
+        start : pd.Timestamp, datetime, date, str, or int
             The start datetime for the request range (inclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int, optional
+        end : pd.Timestamp, datetime, date, str, or int, optional
             The end datetime for the request range (exclusive).
             Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-            Values are forward filled based on the resolution provided.
-            Defaults to the same value as `start`.
+            Defaults to the forward filled value of `start` based on the resolution provided.
         mode : FeedMode or str {'live', 'historical-streaming', 'historical'}, default 'historical-streaming'
             The data feed mode for the request.
         symbols : Iterable[str | int] or str or int, optional
@@ -445,23 +445,23 @@ class MetadataHttpAPI(BentoHttpAPI):
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
         symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
-        params: list[tuple[str, str | None]] = [
-            ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("start", datetime_to_string(start)),
-            ("end", optional_datetime_to_string(end)),
-            ("symbols", ",".join(symbols_list)),
-            ("schema", str(validate_enum(schema, Schema, "schema"))),
-            ("stype_in", str(stype_in_valid)),
-            ("stype_out", str(SType.INSTRUMENT_ID)),
-            ("mode", validate_enum(mode, FeedMode, "mode")),
-        ]
+        data: dict[str, str | None] = {
+            "dataset": validate_semantic_string(dataset, "dataset"),
+            "start": datetime_to_string(start),
+            "end": optional_datetime_to_string(end),
+            "symbols": ",".join(symbols_list),
+            "schema": str(validate_enum(schema, Schema, "schema")),
+            "stype_in": str(stype_in_valid),
+            "stype_out": str(SType.INSTRUMENT_ID),
+            "mode": validate_enum(mode, FeedMode, "mode"),
+        }
 
         if limit is not None:
-            params.append(("limit", str(limit)))
+            data["limit"] = str(limit)
 
-        response: Response = self._get(
+        response: Response = self._post(
             url=self._base_url + ".get_cost",
-            params=params,
+            data=data,
             basic_auth=True,
         )
 
