@@ -199,7 +199,7 @@ class _SessionProtocol(DatabentoLiveProtocol):
         self._metadata: SessionMetadata = metadata
         self._user_callbacks = user_callbacks
         self._user_streams = user_streams
-        self._last_ts_event: pd.Timestamp | None = None
+        self._last_ts_event: int | None = None
 
     def received_metadata(self, metadata: databento_dbn.Metadata) -> None:
         if self._metadata:
@@ -228,7 +228,7 @@ class _SessionProtocol(DatabentoLiveProtocol):
         self._dispatch_callbacks(record)
         if self._dbn_queue.is_enabled():
             self._queue_for_iteration(record)
-        self._last_ts_event = record.pretty_ts_event
+        self._last_ts_event = record.ts_event
 
         return super().received_record(record)
 
@@ -332,6 +332,7 @@ class LiveSession:
         self._transport: asyncio.Transport | None = None
         self._session_id: str | None = None
 
+        self._subscription_counter = 0
         self._subscriptions: list[SubscriptionRequest] = []
         self._reconnect_policy = ReconnectPolicy(reconnect_policy)
         self._reconnect_task: asyncio.Task[None] | None = None
@@ -440,8 +441,7 @@ class LiveSession:
                 return
             if self._transport.can_write_eof():
                 self._transport.write_eof()
-            else:
-                self._transport.close()
+            self._transport.close()
 
     def start(self) -> None:
         """
@@ -500,6 +500,7 @@ class LiveSession:
             if self._protocol is None:
                 self._connect(dataset=dataset)
 
+            self._subscription_counter += 1
             self._subscriptions.extend(
                 self._protocol.subscribe(
                     schema=schema,
@@ -507,14 +508,18 @@ class LiveSession:
                     stype_in=stype_in,
                     start=start,
                     snapshot=snapshot,
+                    subscription_id=self._subscription_counter,
                 ),
             )
 
     def terminate(self) -> None:
-        if self._transport is None:
-            return
-        self._transport.abort()
-        self._cleanup()
+        with self._lock:
+            if self._transport is None:
+                return
+            if self._transport.can_write_eof():
+                self._transport.write_eof()
+            self._transport.abort()
+            self._cleanup()
 
     async def wait_for_close(self) -> None:
         """
@@ -653,7 +658,7 @@ class LiveSession:
                     if self._protocol._last_ts_event is not None:
                         gap_start = pd.Timestamp(self._protocol._last_ts_event, tz="UTC")
                     elif self._metadata.data is not None:
-                        gap_start = self._metadata.data.start
+                        gap_start = pd.Timestamp(self._metadata.data.start, tz="UTC")
                     else:
                         gap_start = pd.Timestamp.utcnow()
 
@@ -670,6 +675,7 @@ class LiveSession:
                             stype_in=sub.stype_in,
                             snapshot=bool(sub.snapshot),
                             start=None,
+                            subscription_id=sub.id,
                         )
 
                     if should_restart:
